@@ -7,13 +7,16 @@ function(previous, newx, k=NA){
   tr = c(previous$input$tr, previous$results$newtr)
 
   if(is.na(k)){
-    pbaResults = pba(x=x, tr=tr, newx=newx, k=previous$input$k, global=previous$input$global)
+    pbaResults = pba(x=x, tr=tr, newx=newx, k=previous$input$k, 
+                     global=previous$input$global)
   }else{
     if(k == previous$input$k){
-      pbaResults = pba(x=x, tr=tr, newx=newx, k=previous$input$k, global=previous$input$global)
+      pbaResults = pba(x=x, tr=tr, newx=newx, k=previous$input$k, 
+                       global=previous$input$global)
     }else{
       ## warn if k is changing from previous allocation
-      warning(paste('Balancing parameter k changed from',round(previous$input$k,5),'to',round(k,5), sep=' '))
+      warning(paste('Balancing parameter k changed from',
+                    round(previous$input$k,5),'to',round(k,5), sep=' '))
       pbaResults = pba(x=x, tr=tr, newx=newx, k=k, global=previous$input$global)
     }
   }
